#include "font.h"
#include <stdio.h>
#include "minilcd.h"

//SPI写入

void lcd_io_config()
{
  Out(LCD_SCK);
  Out(LCD_SI);
  Out(LCD_CS);
  Out(LCD_CD);
  //LCD_init();
}

void SPI_write(unsigned char dat)
{
  for(unsigned char i = 0; i < 8; i++)
  {
    Clr(LCD_SCK);
    if (dat & 0x80)
      {
        Set(LCD_SI);
      }
    else
      {
        Clr(LCD_SI);
      }
    dat <<= 1;
    Set(LCD_SCK);
  }
  Clr(LCD_SCK);
}
 
//向LCD写入命令
void write_cmd(unsigned char dat)
{
  Clr(LCD_CD);  //Wrtie CMD
  SPI_write(dat);
}
 
//向LCD写入数据
void write_dat(unsigned char dat)
{
  Set(LCD_CD);  //Wrtie Data
  SPI_write(dat);
}
 
//LCD初始化
void LCD_init(){
  lcd_io_config();
  Clr(LCD_CS);
  Clr(LCD_RST);  delay(20);
  Set(LCD_RST);     //Reset the LCD
  write_cmd(0xe2);  /*软复位*/     delay(5);
  write_cmd(0x2c);  /*升压步聚1*/  delay(5); 
  write_cmd(0x2e);  /*升压步聚2*/  delay(5);
  write_cmd(0x2f);  /*升压步聚3*/  delay(5);
  write_cmd(0x23);  /*粗调对比度，可设置范围0x20～0x27*/
  write_cmd(0x70);  /*微调对比度*/
  write_cmd(0x2f);  /*0x28,微调对比度的值，可设置范围0x00～0x3f*/
  write_cmd(0xa2);  /*1/9偏压比（bias）*/
  write_cmd(0xc0);  /*行扫描顺序：从上到下*/
  write_cmd(0xa1);  /*列扫描顺序：从左到右*/
  write_cmd(0x40);  /*起始行：第一行开始*/
  write_cmd(0xaf);  /*开显示*/
  Set(LCD_CS);
  Clr_LCD();
}

void turn_0()
{
   Clr(LCD_CS);
  write_cmd(0xc0);  /*行扫描顺序：从上到下*/
  write_cmd(0xa1);  /*列扫描顺序：从左到右*/
      Set(LCD_CS);
      Clr_LCD();
}

void turn_180()
{
   Clr(LCD_CS);
  write_cmd(0xc8);  /*行扫描顺序：从上到下*/
  write_cmd(0xa0);  /*列扫描顺序：从左到右*/
      Set(LCD_CS);
      Clr_LCD();
}

 
//LCD 光标地址设定
void LCD_add(unsigned page, unsigned column)
{
  write_cmd(0xb0 + page);
  write_cmd(0x10 + ((column>>4) & 0x0f));
  write_cmd(column & 0x0f);
}
 
//LCD 屏幕内容清除
void Clr_LCD()
{
  unsigned char i,j;
  Clr(LCD_CS);
  for(i=0;i<9;i++)
  {
    write_cmd(0xb0 + i);
    write_cmd(0x10);
    write_cmd(0x00);
    for(j=0;j<132;j++)
    {
        write_dat(0x00);
    }
  }
  Set(LCD_CS);
}
 
//在某一个位置上显示一个字符
void Dis_char(unsigned char line, unsigned char column, char *chr)
{
  unsigned char page = line * 2;
  Clr(LCD_CS);
  for (unsigned char i = 0; i < 2; i++)
  {
    LCD_add(page + i, column);
    for (unsigned j = 0; j < 8; j++)
    {
      int loc = (*chr - 32) * 16 + j + i * 8;
      write_dat(pgm_read_byte_near(ascii+loc));
    }
  }
  Set(LCD_CS);
}
 
//在某一个位置上显示一个字符串
void Dis_str(unsigned char line, unsigned char column, char *str)
{
  lcd_io_config();
  while(*str)
  {
    Dis_char(line, column, str);
    column += 8;
    str++;
  }
}
